Class: Google::Maps::FleetEngine::V1::ListVehiclesRequest
- Inherits:
-
Object
- Object
- Google::Maps::FleetEngine::V1::ListVehiclesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/maps/fleetengine/v1/vehicle_api.rb
Overview
ListVehicles request message.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Optional.
-
#header ⇒ ::Google::Maps::FleetEngine::V1::RequestHeader
The standard Fleet Engine request header.
-
#maximum_staleness ⇒ ::Google::Protobuf::Duration
Restricts the response to vehicles that have sent location updates to Fleet Engine within the specified duration.
-
#minimum_capacity ⇒ ::Google::Protobuf::Int32Value
Specifies the required minimum capacity of the vehicle.
-
#on_trip_only ⇒ ::Boolean
Only return the vehicles with current trip(s).
-
#page_size ⇒ ::Integer
The maximum number of vehicles to return.
-
#page_token ⇒ ::String
The value of the
next_page_tokenprovided by a previous call toListVehiclesso that you can paginate through groups of vehicles. -
#parent ⇒ ::String
Required.
-
#required_attributes ⇒ ::Array<::String>
Callers can form complex logical operations using any combination of the
required_attributes,required_one_of_attributes, andrequired_one_of_attribute_setsfields. -
#required_one_of_attribute_sets ⇒ ::Array<::String>
required_one_of_attribute_setsprovides additional functionality. -
#required_one_of_attributes ⇒ ::Array<::String>
Restricts the response to vehicles with at least one of the specified attributes in each
VehicleAttributeList. -
#trip_types ⇒ ::Array<::Google::Maps::FleetEngine::V1::TripType>
Restricts the response to vehicles that support at least one of the specified trip types.
-
#vehicle_state ⇒ ::Google::Maps::FleetEngine::V1::VehicleState
Restricts the response to vehicles that have this vehicle state.
-
#vehicle_type_categories ⇒ ::Array<::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category>
Required.
-
#viewport ⇒ ::Google::Geo::Type::Viewport
Optional.
Instance Attribute Details
#filter ⇒ ::String
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#header ⇒ ::Google::Maps::FleetEngine::V1::RequestHeader
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#maximum_staleness ⇒ ::Google::Protobuf::Duration
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minimum_capacity ⇒ ::Google::Protobuf::Int32Value
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#on_trip_only ⇒ ::Boolean
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#required_attributes ⇒ ::Array<::String>
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#required_one_of_attribute_sets ⇒ ::Array<::String>
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#required_one_of_attributes ⇒ ::Array<::String>
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#trip_types ⇒ ::Array<::Google::Maps::FleetEngine::V1::TripType>
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vehicle_state ⇒ ::Google::Maps::FleetEngine::V1::VehicleState
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vehicle_type_categories ⇒ ::Array<::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category>
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#viewport ⇒ ::Google::Geo::Type::Viewport
533 534 535 536 |
# File 'proto_docs/google/maps/fleetengine/v1/vehicle_api.rb', line 533 class ListVehiclesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |