Class: Google::Maps::FleetEngine::V1::Vehicle

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/maps/fleetengine/v1/vehicles.rb

Overview

Vehicle metadata.

Defined Under Namespace

Classes: VehicleType

Instance Attribute Summary collapse

Instance Attribute Details

#attributes::Array<::Google::Maps::FleetEngine::V1::VehicleAttribute>



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#back_to_back_enabled::Boolean



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#current_route_segment::String



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#current_route_segment_end_point::Google::Maps::FleetEngine::V1::TripWaypoint



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#current_route_segment_traffic::Google::Maps::FleetEngine::V1::TrafficPolylineData



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#current_route_segment_version::Google::Protobuf::Timestamp (readonly)



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#current_trips::Array<::String> (readonly)



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#device_settings::Google::Maps::FleetEngine::V1::DeviceSettings



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#eta_to_first_waypoint::Google::Protobuf::Timestamp



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#last_location::Google::Maps::FleetEngine::V1::VehicleLocation



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#license_plate::Google::Maps::FleetEngine::V1::LicensePlate



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#maximum_capacity::Integer



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#name::String (readonly)



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end


137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#past_locations::Array<::Google::Maps::FleetEngine::V1::VehicleLocation>



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#remaining_distance_meters::Google::Protobuf::Int32Value



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#remaining_time_seconds::Google::Protobuf::Int32Value



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#route::Array<::Google::Maps::FleetEngine::V1::TerminalLocation>

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns Deprecated: Use Vehicle.waypoints instead.



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#supported_trip_types::Array<::Google::Maps::FleetEngine::V1::TripType>



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#vehicle_state::Google::Maps::FleetEngine::V1::VehicleState



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#vehicle_type::Google::Maps::FleetEngine::V1::Vehicle::VehicleType



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#waypoints::Array<::Google::Maps::FleetEngine::V1::TripWaypoint>



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end

#waypoints_version::Google::Protobuf::Timestamp (readonly)



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'proto_docs/google/maps/fleetengine/v1/vehicles.rb', line 137

class Vehicle
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of vehicle.
  # @!attribute [rw] category
  #   @return [::Google::Maps::FleetEngine::V1::Vehicle::VehicleType::Category]
  #     Vehicle type category
  class VehicleType
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Vehicle type categories
    module Category
      # Default, used for unspecified or unrecognized vehicle categories.
      UNKNOWN = 0

      # An automobile.
      AUTO = 1

      # Any vehicle that acts as a taxi (typically licensed or regulated).
      TAXI = 2

      # Generally, a vehicle with a large storage capacity.
      TRUCK = 3

      # A motorcycle, moped, or other two-wheeled vehicle
      TWO_WHEELER = 4

      # Human-powered transport.
      BICYCLE = 5

      # A human transporter, typically walking or running, traveling along
      # pedestrian pathways.
      PEDESTRIAN = 6
    end
  end
end